==> opennebula-6.99.85-1-amd64.tar.gz: opennebula-6.99.85/src/fireedge/src/client/assets/languages/es_ES.js <==
lang="es_ES"
locale={
  "":"",
  "children":"Hijo",
  "Address Range":"Rango de Red",
  "Detach":"Separar",
  "Delete Address Range":"Borrar rango de red",
  "Delete":"Borrar",
  "VMs":"MVs",
  "Hosts":"Hosts",
  "Networks":"Redes",
  "Users":"Usuarios",
  "Templates":"Plantillas",
  "Groups":"Grupos",
  "Datastores":"Datastores",
  "Services":"Servicios",
  "Zones":"Zonas",
  "Security groups":"Grupos de seguridad",
  "VDCs":"VDCs",
  "Virtual Routers":"Routers Virtual",
  "Marketplaces":"Tienda de Aplicaciones",
  "Apps":"Aplicaciones",
  "VM Groups":"Grupos MV",
  "Network Templates":"Plantilla de Red",
  "BackupJob":"BackupJobs",
  "Identifier":"Identificador",
  "All":"Todo",
  "Use":"Utilice",
  "Manage":"Administrar",
  "Admin":"Administrador",
  "Create":"Crear",
  "First":"Primero",
  "Used":"Usado",
  "Total leases":"Reservas totales",
  "Remove":"Quitar",
  "Edit":"Editar",
  "Clone":"Clon",
  "Tiers":"Niveles",
  "Deploy":"Desplegar",
  "Priority":"Prioridad",
  "Owner":"Propietario",
  "Group":"Grupo",
  "Virtual networks":"Redes virtuales",
  "Provision ID":"ID de Provision",
  "label":"Etiqueta",
  "Target device":"Dispositivo de destino",
  "Datastore":"Datastore",
  "Monitoring":"Monitorizando",
  "Allocated CPU":"CPU Asignada",
  "Allocated Memory":"Memoria Asignada",
  "Version":"Version",
  "Marketplace":"Tienda de Aplicaciones",
  "Zone":"Zona",
  "Device":"Dispositivo",
  "Vendor":"Fabricante",
  "Class":"Clase",
  "Total updated VMs":"Total de VMs actualizadas",
  "Total outdated VMs":"",
  "Total error VMs":"Total de VMs en error",
  "Roles":"Roles",
  "Created":"",
  "Auth Driver":"",
  "Done":"Hecho",
  "Started":"",
  "Virtual CPU":"CPU Virtual",
  "Memory":"Memoria",
  "Hostname":"Nombre de Host",
  "IP":"IP",
  "Affined Roles":"",
  "text":"texto",
  "finalWord":"",
  "Export":"",
  "Start Date":"",
  "EndDate":"",
  "title":"Titulo",
  "Unit memory":"",
  "Submit":"Enviar",
  "Protocol":"Protocolo",
  "Type":"Tipo",
  "Range":"Rango",
  "Network":"Red",
  "ICMP Type":"Tipo ICMP",
  "ICMPv6 Type":"Tipo ICMPv6",
  "PROTOCOL":"",
  "RULE_TYPE":"",
  "RANGE":"",
  "network":"red",
  "Default value":"Valor por defecto",
  "Mandatory":"Obligatorio",
  "No":"No",
  "Extra":"Extra",
  "Advanced Parameters":"",
  "Elasticity Policies":"",
  "Adjust":"Ajustar",
  "Cooldown":"Congelar",
  "Period":"Periodo",
  "Scheduled Policies":"",
  "TIMEFORMAT":"",
  "Time Expression":"",
  "Time Format":"",
  "Select":"",
  "NIC Alias":"",
  "Alias":"Alias",
  "Rows per page":"",
  "RDP":"RDP",
  "ID":"ID",
  "Select a VM Template":"",
  "Role Configuration":"",
  "Name":"Nombre",
  "Enter a name for this role":"",
  "Select a network for this role":"",
  "Role Elasticity":"Elasticidad de Rol",
  "Min VMs":"Min MVs",
  "Max VMs":"Max MVs",
  "Adjustment type":"",
  "Positive or negative adjustment":"",
  "Add role":"",
  "Role Details":"",
  "Role Name":"Nombre del Rol",
  "Parent roles":"Roles padre",
  "VM Templates":"Plantillas de MV",
  "Registration time":"Fecha de registro",
  "SSH connection":"",
  "Security group":"",
  "Configured NICs":"",
  "Network name":"Nombre de red",
  "Add NIC":"",
  "Add a NIC to Start Configuring":"",
  "Search":"Buscar",
  "Show mandatory only":"",
  "Value":"Valor",
  "in":"",
  "Warning before":"",
  "WARNING_PERIOD":"",
  "Potential Use Cases":"",
  "Affined":"Afinidad",
  "Add Group":"",
  "Affined Groups":"",
  "Host Affinity":"",
  "Status":"Estado",
  "Affined Hosts":"",
  "Host":"Host",
  "VM Group Configuration":"",
  "New Role":"",
  "None":"Ninguna",
  "Show all":"Mostrar todo",
  "Show all owned by the user or his groups":"",
  "Show all owned by the user":"",
  "There is no data available":"No hay datos disponibles",
  "Back":"Regresar",
  "Divide Window":"",
  "Low":"",
  "Medium":"",
  "High":"",
  "tooltipTitle":"",
  "Persistent":"Persistente",
  "Non Persistent":"",
  "Disk type":"Tipo de disco",
  "Running":"Ejecutando",
  "Total":"Total",
  "Provider":"Proveedor",
  "Menu":"",
  "Show columns":"",
  "Manage columns":"",
  "Filter":"Filtrar",
  "Hide column":"",
  "Unsort":"",
  "Sort by ASC":"",
  "Sort by DESC":"",
  "Sort":"",
  "Header":"Encabezado",
  "Refresh":"Refrescar",
  "Saved in the Users template":"Guardado en la plantilla de usuario",
  "Previous":"",
  "of":"",
  "Next":"Siguiente",
  "Download Default Image":"",
  "Template":"Plantilla",
  "Total VMs":"Total de MVs",
  "Filters":"Filtros",
  "Endpoint":"Punto Terminal",
  "value":"",
  "Group By":"",
  "VM":"MV",
  "User":"Usuario",
  "Chart Type":"",
  "Line Chart":"",
  "Bar Chart":"",
  "Area Chart":"",
  "Table Chart":"",
  "Attributes":"Atributos",
  "name":"nombre",
  "Permissions":"Permisos",
  "Free CPU":"CPU Libre",
  "Used CPU":"CPU Usada",
  "Free Memory":"",
  "Used memory":"Memoria utilizada",
  "Update":"Actualizar",
  "Flatten":"Flatten",
  "Revert":"Revertir",
  "Apply":"Aplicar",
  "How to use Quota Controls":"",
  "enter Resource IDs over which this quota will apply":"",
  "this further qualifies the quota type to a more specific attribute":"",
  "Resource IDs":"",
  "Select or type a Resource ID":"",
  "VM Quota":"",
  "Datastore Quota":"",
  "Network Quota":"",
  "Image Quota":"",
  "Quota Controls":"",
  "Severity":"",
  "All Severities":"",
  "Asc":"",
  "Desc":"",
  "Cardinality":"Cardinalidad",
  "Force":"Forzar",
  "Scale":"Escalar",
  "Attachments":"",
  "Add comment to close the ticket":"",
  "Edit Public SSH Key":"",
  "Edit Private SSH Key":"",
  "Edit SSH Key Passphrase":"",
  "Save Changes":"",
  "Cancel":"Cancelar",
  "Save":"Salvar",
  "Primary":"Primario",
  "Secondary":"",
  "Request ID":"",
  "Time when the state changed":"Hora del cambio de estado",
  "Total time in this state":"Tiempo total en este estado",
  "Prolog time for this state":"Tiempo en prolog para este estado",
  "Real CPU":"CPU Real",
  "Real Memory":"Memorial Real",
  "Cores":"Nucleos",
  "Sockets":"Conectores",
  "Attach Security Group":"Adjuntar grupo de seguridad",
  "Detach Security Group":"Separar grupo de seguridad",
  "Net RX":"Red RX",
  "Net TX":"Red TX",
  "Net download speed":"Velocidad de descarga",
  "Net upload speed":"Velocidad de subida",
  "Save as":"Guardar como",
  "Resize":"Redimensionar",
  "Disk read bytes":"Bytes de lectura de disco",
  "Disk write bytes":"Bytes de escritura de disco",
  "Disk read IOPS":"Disco de lectura IOPS",
  "Disk write IOPS":"IOPS de escritura de disco",
  "Roles Affinity":"Afinidad de Roles",
  "Strategy":"Estrategia",
  "State":"Estado",
  "Ready status gate":"Puerta de estado listo",
  "Other":"Otros",
  "Ownership":"Propiedad",
  "Locate on table":"",
  "Close":"Cerrar",
  "Guacamole State":"Estado Guacamole",
  "Wrong username or password":"",
  "Credentials":"Credenciales",
  "Start time":"Hora de inicio",
  "Succesfully changed password":"",
  "Press enter to create a new label":"Pulse intro para crear una nueva etiqueta",
  "Token":"Token",
  "Get a new token":"Obtener un nuevo token",
  "Scan this Qr":"",
  "Select request":"Seleccionar Solicitud",
  "Clear error messages and warnings from selects Virtual Machines":"",
  "VMRC State":"Estado del VMRC",
  "Daily":"",
  "Weekly":"Semanalmente",
  "Monthly":"Mensualmente",
  "Yearly":"Anualmente",
  "On":"En",
  "VMRC":"VMRC",
  "Charter":"Charter",
  "Active":"Activo",
  "Snapshot":"Snapshot",
  "Reconnect":"Reconectar",
  "Full screen":"Pantalla Completa",
  "Screenshot":"Captura de pantalla",
  "Part of":"Parte de",
  "Made with":"Hecho con",
  "Clear":"Limpiar",
  "Today":"Hoy",
  "Finish":"Finalizar",
  "Context":"Contexto",
  "Backup":"Copia de seguridad",
  "Switch group":"Cambiar grupo",
  "Sign Out":"Salir",
  "Switch view":"Cambiar vista",
  "Not found":"No se encuentra",
  "ensuredTitle":"",
  "ensuredDescription":"",
  "Filter by":"Filtrar por",
  "No labels":"",
  "Label":"Etiqueta",
  "Sort by":"",
  "message":"Mensaje",
  "Cannot connect to OneFlow server":"No se pudo conectar al servidor OneFlow",
  "Retry":"",
  "Copied to clipboard":"Copiado al portapapeles",
  "col":"col",
  "Free":"Libre",
  "Pages":"Paginas",
  "Usage":"Uso",
  "Prolog":"",
  "Capacity":"Capacidad",
  "User Template":"Plantilla de usuario",
  "Dismiss":"Descartar",
  "Sign In":"Ingresar",
  "Press Escape to cancel":"Presiona Escape para cancelar",
  "Labels":"Etiquetas",
  "Enter Verification Code":"",
  "Two Factor Authentication":"Autenticacion en dos pasos",
  "Register authentication App":"",
  "Settings":"Ajustes",
  "Or":"",
  "Get an account":"",
  "Commercial Support":"",
  "Additional Help Resources":"",
  "Community":"Comunidad",
  "Commercial Support Requests":"",
}

==> opennebula-7.1.80-1-amd64.tar.gz: opennebula-7.1.80/src/fireedge/src/client/assets/languages/es_ES.js <==
lang="es_ES"
locale={
  "":"",
  "children":"Hijo",
  "Address Range":"Rango de Red",
  "Detach":"Separar",
  "Delete Address Range":"Borrar rango de red",
  "Delete":"Borrar",
  "VMs":"MVs",
  "Hosts":"Hosts",
  "Networks":"Redes",
  "Users":"Usuarios",
  "Templates":"Plantillas",
  "Groups":"Grupos",
  "Datastores":"Datastores",
  "Services":"Servicios",
  "Zones":"Zonas",
  "Security groups":"Grupos de seguridad",
  "VDCs":"VDCs",
  "Virtual Routers":"Routers Virtual",
  "Marketplaces":"Tienda de Aplicaciones",
  "Apps":"Aplicaciones",
  "VM Groups":"Grupos MV",
  "Network Templates":"Plantilla de Red",
  "BackupJob":"BackupJobs",
  "Identifier":"Identificador",
  "All":"Todo",
  "Use":"Utilice",
  "Manage":"Administrar",
  "Admin":"Administrador",
  "Create":"Crear",
  "First":"Primero",
  "Used":"Usado",
  "Total leases":"Reservas totales",
  "Remove":"Quitar",
  "Edit":"Editar",
  "Clone":"Clon",
  "Tiers":"Niveles",
  "Deploy":"Desplegar",
  "Priority":"Prioridad",
  "Owner":"Propietario",
  "Group":"Grupo",
  "Virtual networks":"Redes virtuales",
  "Provision ID":"ID de Provision",
  "label":"Etiqueta",
  "Target device":"Dispositivo de destino",
  "Datastore":"Datastore",
  "Monitoring":"Monitorizando",
  "Allocated CPU":"CPU Asignada",
  "Allocated Memory":"Memoria Asignada",
  "Version":"Version",
  "Marketplace":"Tienda de Aplicaciones",
  "Zone":"Zona",
  "Device":"Dispositivo",
  "Vendor":"Fabricante",
  "Class":"Clase",
  "VM":"MV",
  "repeat":"",
  "end":"",
  "Total updated VMs":"Total de VMs actualizadas",
  "Total outdated VMs":"",
  "Total error VMs":"Total de VMs en error",
  "Roles":"Roles",
  "Created":"",
  "Auth Driver":"",
  "Done":"Hecho",
  "Started":"",
  "Virtual CPU":"CPU Virtual",
  "Memory":"Memoria",
  "Host":"Host",
  "Hostname":"Nombre de Host",
  "IP":"IP",
  "Affined Roles":"",
  "text":"texto",
  "finalWord":"",
  "Export":"",
  "Start Date":"",
  "EndDate":"",
  "title":"Titulo",
  "Unit memory":"",
  "Protocol":"Protocolo",
  "Type":"Tipo",
  "Range":"Rango",
  "Network":"Red",
  "ICMP Type":"Tipo ICMP",
  "ICMPv6 Type":"Tipo ICMPv6",
  "PROTOCOL":"",
  "RULE_TYPE":"",
  "RANGE":"",
  "network":"red",
  "Adjust":"Ajustar",
  "Cooldown":"Congelar",
  "Period":"Periodo",
  "format":"",
  "Time Format":"",
  "Time Expression":"",
  "in":"",
  "Warning before":"",
  "WARNING_PERIOD":"",
  "PERIOD":"",
  "Potential Use Cases":"",
  "Affined":"Afinidad",
  "Add Group":"",
  "Affined Groups":"",
  "Host Affinity":"",
  "ID":"ID",
  "Name":"Nombre",
  "Status":"Estado",
  "Rows per page":"",
  "Role Configuration":"",
  "Enter a name for this role":"",
  "Affined Hosts":"",
  "VM Group Configuration":"",
  "New Role":"",
  "Role Details":"",
  "Role Name":"Nombre del Rol",
  "None":"Ninguna",
  "Loaded":"",
  "SSH connection":"",
  "Security group":"",
  "Configured NICs":"",
  "Network name":"Nombre de red",
  "Add NIC":"",
  "Add a NIC to Start Configuring":"",
  "Search":"Buscar",
  "Show mandatory only":"",
  "No":"No",
  "Value":"Valor",
  "Show all":"Mostrar todo",
  "Show all owned by the user or his groups":"",
  "Show all owned by the user":"",
  "There is no data available":"No hay datos disponibles",
  "Low":"",
  "Medium":"",
  "High":"",
  "tooltipTitle":"",
  "Persistent":"Persistente",
  "Non Persistent":"",
  "Disk type":"Tipo de disco",
  "Running":"Ejecutando",
  "Total":"Total",
  "Provider":"Proveedor",
  "Menu":"",
  "Show columns":"",
  "Manage columns":"",
  "Filter":"Filtrar",
  "Hide column":"",
  "Unsort":"",
  "Sort by ASC":"",
  "Sort by DESC":"",
  "Sort":"",
  "Header":"Encabezado",
  "Refresh":"Refrescar",
  "Saved in the Users template":"Guardado en la plantilla de usuario",
  "Card View":"",
  "List View":"",
  "Number of rows per page":"",
  "of":"",
  "Filters":"Filtros",
  "Download Default Image":"",
  "Template":"Plantilla",
  "Total VMs":"Total de MVs",
  "Endpoint":"Punto Terminal",
  "value":"",
  "Group By":"",
  "User":"Usuario",
  "Chart Type":"",
  "Line Chart":"",
  "Bar Chart":"",
  "Area Chart":"",
  "Table Chart":"",
  "Attributes":"Atributos",
  "name":"nombre",
  "Permissions":"Permisos",
  "Update":"Actualizar",
  "Flatten":"Flatten",
  "Revert":"Revertir",
  "How to use Quota Controls":"",
  "enter Resource IDs over which this quota will apply":"",
  "this further qualifies the quota type to a more specific attribute":"",
  "VM Quota":"",
  "Datastore Quota":"",
  "Network Quota":"",
  "Image Quota":"",
  "Quota Controls":"",
  "Severity":"",
  "All Severities":"",
  "Asc":"",
  "Desc":"",
  "Cardinality":"Cardinalidad",
  "Force":"Forzar",
  "Attachments":"",
  "Add comment to close the ticket":"",
  "Edit Public SSH Key":"",
  "Edit Private SSH Key":"",
  "Edit SSH Key Passphrase":"",
  "Primary Group":"Grupo Primario",
  "Secondary Groups":"Grupos Secundarios",
  "Request ID":"",
  "Time when the state changed":"Hora del cambio de estado",
  "Total time in this state":"Tiempo total en este estado",
  "Prolog time for this state":"Tiempo en prolog para este estado",
  "Real CPU":"CPU Real",
  "Real Memory":"Memorial Real",
  "Cores":"Nucleos",
  "Sockets":"Conectores",
  "Alias":"Alias",
  "Attach Security Group":"Adjuntar grupo de seguridad",
  "Detach Security Group":"Separar grupo de seguridad",
  "Net download speed":"Velocidad de descarga",
  "Net upload speed":"Velocidad de subida",
  "Save as":"Guardar como",
  "Resize":"Redimensionar",
  "Disk read bytes":"Bytes de lectura de disco",
  "Disk write bytes":"Bytes de escritura de disco",
  "Disk read IOPS":"Disco de lectura IOPS",
  "Disk write IOPS":"IOPS de escritura de disco",
  "Roles Affinity":"Afinidad de Roles",
  "Back":"Regresar",
  "Full screen":"Pantalla Completa",
  "Close":"Cerrar",
  "Guacamole State":"Estado Guacamole",
  "Wrong username or password":"",
  "Primary":"Primario",
  "Registration time":"Fecha de registro",
  "Credentials":"Credenciales",
  "Start time":"Hora de inicio",
  "State":"Estado",
  "Succesfully changed password":"",
  "Token":"Token",
  "Scan this Qr":"",
  "Select request":"Seleccionar Solicitud",
  "Clear error messages and warnings from selects Virtual Machines":"",
  "Charter":"Charter",
  "Active":"Activo",
  "Snapshot":"Snapshot",
  "Reconnect":"Reconectar",
  "Submit":"Enviar",
  "Screenshot":"Captura de pantalla",
  "Part of":"Parte de",
  "Made with":"Hecho con",
  "Cancel":"Cancelar",
  "Clear":"Limpiar",
  "Today":"Hoy",
  "Finish":"Finalizar",
  "Next":"Siguiente",
  "Context":"Contexto",
  "Capacity":"Capacidad",
  "Switch group":"Cambiar grupo",
  "Sign Out":"Salir",
  "Settings":"Ajustes",
  "Switch view":"Cambiar vista",
  "Not found":"No se encuentra",
  "Filter by":"Filtrar por",
  "No labels":"",
  "Filter by label":"",
  "Label":"Etiqueta",
  "Sort by":"",
  "message":"Mensaje",
  "Cannot connect to OneFlow server":"No se pudo conectar al servidor OneFlow",
  "Retry":"",
  "Copied to clipboard":"Copiado al portapapeles",
  "col":"col",
  "Free":"Libre",
  "Pages":"Paginas",
  "Usage":"Uso",
  "Prolog":"",
  "User Template":"Plantilla de usuario",
  "Dismiss":"Descartar",
  "My Dashboard":"",
  "Sign In Now":"",
  "Press Escape to cancel":"Presiona Escape para cancelar",
  "Enter Verification Code":"",
  "Or":"",
  "Get an account":"",
  "Commercial Support":"",
  "Additional Help Resources":"",
  "Community":"Comunidad",
  "Commercial Support Requests":"",
}
